@@ -73,6 +73,7 @@ struct _glLabelObjectPrivate {
 
 enum {
         CHANGED,
+        MOVED,
         LAST_SIGNAL
 };
 
@@ -101,7 +102,7 @@ static void     set_size                  (glLabelObject      *object,
 /*****************************************************************************/
 /* Boilerplate object stuff.                                                 */
 /*****************************************************************************/
-G_DEFINE_TYPE (glLabelObject, gl_label_object, G_TYPE_OBJECT);
+G_DEFINE_TYPE (glLabelObject, gl_label_object, G_TYPE_OBJECT)
 
 
 static void
@@ -129,6 +130,16 @@ gl_label_object_class_init (glLabelObjectClass *class)
 			      G_TYPE_NONE,
 			      0);
 
+	signals[MOVED] =
+		g_signal_new ("moved",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (glLabelObjectClass, moved),
+			      NULL, NULL,
+			      gl_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
+
 	gl_debug (DEBUG_LABEL, "END");
 }
 
@@ -226,7 +237,7 @@ gl_label_object_dup (glLabelObject *src_object,
 	shadow_state      = gl_label_object_get_shadow_state   (src_object);
 
 	gl_label_object_set_position (dst_object, x, y, FALSE);
-	gl_label_object_set_size     (dst_object, w, h, FALSE);
+	gl_label_object_set_raw_size (dst_object, w, h, FALSE);
 	gl_label_object_set_matrix   (dst_object, &matrix);
 	gl_label_object_set_shadow_offset  (dst_object, shadow_x, shadow_y, FALSE);
 	gl_label_object_set_shadow_color   (dst_object, shadow_color_node, FALSE);
@@ -388,9 +399,10 @@ gl_label_object_set_position (glLabelObject *object,
 
 		object->priv->x = x;
 		object->priv->y = y;
-	}
 
-        gl_label_object_emit_changed (object);
+                g_signal_emit (G_OBJECT(object), signals[MOVED], 0);
+
+	}
 
 	gl_debug (DEBUG_LABEL, "END");
 }
@@ -422,9 +434,9 @@ gl_label_object_set_position_relative (glLabelObject *object,
 		gl_debug (DEBUG_LABEL, "       x = %f, y= %f",
 			  object->priv->x,
 			  object->priv->y);
-	}
 
-        gl_label_object_emit_changed (object);
+                g_signal_emit (G_OBJECT(object), signals[MOVED], 0);
+	}
 
 	gl_debug (DEBUG_LABEL, "END");
 }
@@ -500,6 +512,26 @@ gl_label_object_set_size (glLabelObject *object,
 }
 
 
+/*****************************************************************************/
+/* Set raw size of object.                                                   */
+/*****************************************************************************/
+void
+gl_label_object_set_raw_size (glLabelObject *object,
+                              gdouble        w,
+                              gdouble        h,
+                              gboolean       checkpoint)
+{
+	gl_debug (DEBUG_LABEL, "START");
+
+	g_return_if_fail (object && GL_IS_LABEL_OBJECT (object));
+
+        set_size (object, w, h, checkpoint);
+        object->priv->aspect_ratio = h / w;
+
+	gl_debug (DEBUG_LABEL, "END");
+}
+
+
 /*****************************************************************************/
 /* Set size of object honoring current aspect ratio.                         */
 /*****************************************************************************/
